@@ -1,17 +1,17 @@
 package Log::ger::Level::Like::RubyLogging;
 
 our $DATE = '2017-08-03'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use Log::ger ();
 
 %Log::ger::Levels = (
     unknown => 0,
-    fatal   => 1,
-    error   => 2,
-    warn    => 3,
-    info    => 4,
-    debug   => 5,
+    fatal   => 10,
+    error   => 20,
+    warn    => 30,
+    info    => 40,
+    debug   => 50,
 );
 
 %Log::ger::Level_Aliases = (
@@ -33,7 +33,7 @@ Log::ger::Level::Like::RubyLogging - Define logging levels like Ruby's logging l
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -49,12 +49,12 @@ output destinations per log event, custom formatting, and more."
 
 This module changes the L<Log::ger> levels to:
 
- unknown (0)
- fatal (1)
- error (2)
- warn (3)
- info (4)
- debug (5)
+    unknown => 0,
+    fatal   => 10,
+    error   => 20,
+    warn    => 30,
+    info    => 40,
+    debug   => 50,
 
 =head1 SEE ALSO
 
